# BalderHub Package ``balderhub-textual``

This is a BalderHub package for the [Balder](https://docs.balder.dev) test framework. It provides features and different kind of helper 
objects for writing tests for the [Textual Framework](https://textual.textualize.io/) with Balder. If you are new to 
Balder check out the [official documentation](https://docs.balder.dev) first.

## Installation

You can install the latest release with pip:

```
python -m pip install balderhub-textual
```

# Check out the documentation

If you need more information, 
[checkout the ``balderhub-textual`` documentation](https://hub.balder.dev/projects/textual).


# License

This BalderHub package is free and Open-Source

Copyright (c) 2026 Max Stahlschmidt and others

Distributed under the terms of the MIT license